@@ -5,13 +5,13 @@ use strict;
 use warnings;
 
 use Error::Pure qw(err);
-use List::Util qw(none);
+use List::Util 1.33 qw(none);
 use Locale::Language;
 use Readonly;
 
 Readonly::Array our @EXPORT_OK => qw(check_language);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub check_language {
 	my ($self, $key) = @_;
@@ -49,7 +49,7 @@ Mo::utils::Language - Mo language utilities.
 
 =head1 SYNOPSIS
 
- use Mo::utils qw(check_language);
+ use Mo::utils::Language qw(check_language);
 
  check_language($self, $key);
 
@@ -72,7 +72,6 @@ Returns undef.
 
  check_language():
          Language code '%s' isn't ISO 639-1 code.
-         Language with ISO 639-1 code '%s' doesn't exist.
 
 =head1 EXAMPLE1
 
@@ -155,12 +154,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2022-2023 Michal Josef Špaček
+© 2022-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
